/****************************************************************************
 * Functions for obtaining load information.
 * Copyright (C) 2004 Joe Wingbermuehle
 ****************************************************************************/

#include "jwm.h"

#ifdef SHOW_LOAD

static const int LOAD_DELTA = 5;

static int loadHeight;
static Pixmap loadDisplay;
static GC loadGC;
static time_t lastTime;
static float loads[LOAD_WIDTH];

static void UpdateLoadDisplay();

#endif /* SHOW_LOAD */

/****************************************************************************
 ****************************************************************************/
void InitializeLoadDisplay() {
#ifdef SHOW_LOAD
	int x;

	loadHeight = trayHeight - 4;

	loadDisplay = JXCreatePixmap(display, rootWindow, LOAD_WIDTH,
		loadHeight, rootDepth);
	loadGC = JXCreateGC(display, loadDisplay, 0, NULL);

	for(x = 0; x < LOAD_WIDTH; x++) {
		loads[x] = 0.0;
	}

	UpdateLoadDisplay();
#endif
}

/****************************************************************************
 ****************************************************************************/
void DestroyLoadDisplay() {
#ifdef SHOW_LOAD
	JXFreeGC(display, loadGC);
	JXFreePixmap(display, loadDisplay);
#endif
}

/****************************************************************************
 ****************************************************************************/
void UpdateLoadDisplay() {
#ifdef SHOW_LOAD

	float currentLoad = 0.0;
	int loadLines;
	float divideSize, y;
	int x;

	lastTime = time(NULL);

	/* Compute the current load. */
	currentLoad = GetLoad();

	/* Update the array and determine how many load lines to draw. */
	loadLines = (int)currentLoad;
	for(x = 0; x < LOAD_WIDTH - 1; x++) {
		loads[x] = loads[x + 1];
		if((int)loads[x] > loadLines) {
			loadLines = (int)loads[x];
		}
	}
	loads[LOAD_WIDTH - 1] = currentLoad;

	/* Clear the draw area. */
	JXSetForeground(display, loadGC, colors[COLOR_LOAD_BG]);
	JXFillRectangle(display, loadDisplay, loadGC, 0, 0,
		LOAD_WIDTH, loadHeight);

	/* Draw the graph. */
	JXSetForeground(display, loadGC, colors[COLOR_LOAD_FG]);
	for(x = 0; x < LOAD_WIDTH; x++) {
		y = (loads[x] * loadHeight) / (loadLines + 1);
		JXDrawLine(display, loadDisplay, loadGC, x, loadHeight - (int)y,
			x, loadHeight);
	}

	/* Draw load lines */
	divideSize = (float)(loadHeight) / (float)(loadLines + 1);
	JXSetForeground(display, loadGC, colors[COLOR_LOAD_OUTLINE]);
	y = divideSize;
	for(x = 0; x < loadLines; x++) {
		JXDrawLine(display, loadDisplay, loadGC, 0, (int)y,
			LOAD_WIDTH, (int)y);
		y += divideSize;
	}

#endif /* SHOW_LOAD */

}

/****************************************************************************
 ****************************************************************************/
Pixmap GetLoadDisplay() {
#ifdef SHOW_LOAD

	if(time(NULL) - lastTime >= LOAD_DELTA) {
		UpdateLoadDisplay();
	}

	return loadDisplay;
#else
	return None;
#endif
}

