/****************************************************************************
 * Timing functions.
 * Copyright (C) 2004 Joe Wingbermuehle
 ****************************************************************************/

#include "jwm.h"

static const unsigned long MAX_TIME_SECONDS = 30;

/****************************************************************************
 * Get the current time in milliseconds since midnight 1970-01-01 UTC.
 ****************************************************************************/
void GetCurrentTime(TimeType *t) {
	struct timeval val;
	gettimeofday(&val, NULL);
	t->seconds = val.tv_sec;
	t->ms = val.tv_usec / 1000;
}

/****************************************************************************
 * Get the absolute difference between two times in milliseconds.
 * If the difference is larger than a minute, a minute will be reported.
 * Note that the times must be normalized.
 ****************************************************************************/
unsigned long GetTimeDifference(const TimeType *t1, const TimeType *t2) {
	unsigned long temp;

	temp = Abs(t1->seconds - t2->seconds);

	if(temp > 60) {
		return 60 * 1000;
	} else {
		return (temp * 1000) + Abs(t1->ms - t2->ms);
	}

}

/****************************************************************************
 * Not reentrant
 ****************************************************************************/
char *GetShortTimeString() {
	static char str[10];
	time_t clock;
	int x, len;

	clock = time(NULL);
	len = strftime(str, sizeof(str), "%I:%M %p", localtime(&clock));

	if(str[0] == '0') {
		for(x = 0; x < len; x++) {
			str[x] = str[x + 1];
		}
	}

	return str;
}

/****************************************************************************
 * Not reentrant
 ****************************************************************************/
char *GetLongTimeString() {
	static char str[80];
	time_t clock;

	clock = time(NULL);
	strftime(str, sizeof(str), "%a %b %d %Y %H:%I:%S", localtime(&clock));

	return str;
}


